@@ -4,6 +4,7 @@ import sys
 import uuid
 import argparse
 from mfcloud.attach import Terminal, AttachStdinProtocol
+from mfcloud.sync.storage import get_storage, storage_sync
 
 import re
 import os
@@ -18,7 +19,6 @@ from twisted.internet.error import TimeoutError
 from twisted.internet.error import ConnectionRefusedError
 from twisted.python import log
 from mfcloud import metadata
-from mfcloud.sendfile import get_storage, storage_sync
 
 
 def format_epilog():
